AndroidNotificationProxy enum

Controls proxy behaviour for notifications through trusted applications.

Requires Android 12+ (API level 31+) and targeting API 31+.

Inheritance
Available extensions

Values

proxyUnspecified → const AndroidNotificationProxy

Proxy state is not specified — use the system default.

allow → const AndroidNotificationProxy

Always proxy this notification.

deny → const AndroidNotificationProxy

Never proxy this notification.

ifPriorityDegraded → const AndroidNotificationProxy

Proxy if the delivery priority was degraded by the system.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AndroidNotificationProxy>
A constant List of the values in this enum, in order of their declaration.